Entry

Struct Entry 

pub struct Entry<'a, R, ChunkKey, ItemKey, Element>
where R: Record<ChunkKey, ItemKey> + 'a, ChunkKey: BorrowedKey + ?Sized, ChunkKey::Owned: ValidKey, ItemKey: BorrowedKey + ?Sized, ItemKey::Owned: ValidKey,
{ /* private fields */ }
An Entry for an element. This is intended to work in the same way as the Entries from rust’s standard collections API. An Entry refers to an element that we have tried to look up and might or might not have found.

Type Parameters

  • R: The key used to lookup this Entry
  • ChunkKey: The chunk key type of the backing Storage
  • ItemKey: The item key type of the backing Storage
  • Element: The element type of the backing Storage, and also the Element represented by this Entry.

Implementations

Source

impl<'a, R, ChunkKey, ItemKey, Element> Entry<'a, R, ChunkKey, ItemKey, Element>
where R: Record<ChunkKey, ItemKey> + 'a, ChunkKey: BorrowedKey + ?Sized, ChunkKey::Owned: ValidKey, ItemKey: BorrowedKey + ?Sized, ItemKey::Owned: ValidKey, Element: Record<ChunkKey, ItemKey>,

pub fn id(&self) -> &R

Returns the value whose ChunkKey and ItemKey is used to look up this Entry.

pub fn or_insert_with<F>(self, f: F) -> &'a mut Element
where F: FnOnce() -> Element,

Insert a record at this entry if it does not already exist.

pub fn and_modify<F>(self, f: F) -> Self
where F: FnOnce(&mut Element),

Modify this element if it exists. If the element does not exist, nothing happens.

pub fn or_panic(self) -> Self
where R: Debug,

Panic if this element doesn’t exist in Storage.

pub fn get(&self) -> Option<&Element>

Get a reference to the element.

pub fn get_mut(&mut self) -> Option<&mut Element>

Get a mutable reference to the element.

pub fn remove(self) -> Option<Element>

Remove and return the element.

pub fn remove_if<F>(self, f: F) -> Option<Element>
where F: FnMut(&Element) -> bool,

Remove and return the element, only if the predicate is true.